pub struct Component {
pub name: String,
pub template: String,
pub island_js: Option<String>,
pub style_css: Option<String>,
}Expand description
One loaded component.
Fields
name: Stringtemplate: Stringisland_js: Option<String>style_css: Option<String>Implementations
Sourceimpl Component
impl Component
Sourcepub fn from_parts(
name: impl Into<String>,
template: impl Into<String>,
island_js: Option<String>,
style_css: Option<String>,
) -> Self
pub fn from_parts( name: impl Into<String>, template: impl Into<String>, island_js: Option<String>, style_css: Option<String>, ) -> Self
Build a component from its raw parts (used by BOTH project discovery and the embedded built-in loader).
Sourcepub fn render(&self, ctx: &DirectiveContext) -> Result<String, ComponentError>
pub fn render(&self, ctx: &DirectiveContext) -> Result<String, ComponentError>
Render this component for one directive instance to HTML.
The template is registered under a .html name so minijinja’s default
auto-escape callback HTML-escapes {{ attrs.x }} / {{ label }}. The
already-rendered inner markdown is exposed as content, so a template
author writes {{ content | safe }} to splice block content raw.